"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const merge_typedefs_1 = require("./typedefs-mergers/merge-typedefs");
const merge_resolvers_1 = require("./resolvers-mergers/merge-resolvers");
const resolvers_composition_1 = require("../utils/resolvers-composition");
const build_schema_with_resolvers_1 = require("../utils/build-schema-with-resolvers");
const extract_resolvers_from_schema_1 = require("../utils/extract-resolvers-from-schema");
function mergeSchemas({ schemas, typeDefs, resolvers = {}, resolversComposition = {}, exclusions, }) {
    return build_schema_with_resolvers_1.buildSchemaWithResolvers({
        typeDefs: merge_typedefs_1.mergeTypeDefs(typeDefs ? [
            ...schemas,
            typeDefs,
        ] : schemas, { exclusions }),
        resolvers: resolvers_composition_1.composeResolvers(merge_resolvers_1.mergeResolvers([
            ...schemas.map(schema => extract_resolvers_from_schema_1.extractResolversFromSchema(schema)),
            resolvers,
        ], { exclusions }), resolversComposition)
    });
}
exports.mergeSchemas = mergeSchemas;
async function mergeSchemasAsync({ schemas, typeDefs, resolvers = {}, resolversComposition = {}, exclusions, }) {
    const [typeDefsOutput, resolversOutput,] = await Promise.all([
        merge_typedefs_1.mergeTypeDefs(typeDefs ? [
            ...schemas,
            typeDefs,
        ] : schemas, { exclusions }),
        Promise
            .all(schemas.map(async (schema) => extract_resolvers_from_schema_1.extractResolversFromSchema(schema)))
            .then(extractedResolvers => resolvers_composition_1.composeResolvers(merge_resolvers_1.mergeResolvers([
            ...extractedResolvers,
            resolvers,
        ], { exclusions }), resolversComposition)),
    ]);
    return build_schema_with_resolvers_1.buildSchemaWithResolvers({
        typeDefs: typeDefsOutput,
        resolvers: resolversOutput
    });
}
exports.mergeSchemasAsync = mergeSchemasAsync;
//# sourceMappingURL=merge-schemas.js.map