"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const print_schema_with_directives_1 = require("../utils/print-schema-with-directives");
const introspectionQuery_1 = require("graphql/utilities/introspectionQuery");
const buildClientSchema_1 = require("graphql/utilities/buildClientSchema");
const parser_1 = require("graphql/language/parser");
async function loadFromUrl(url, options) {
    let headers = {};
    if (options) {
        if (Array.isArray(options.headers)) {
            headers = options.headers.reduce((prev, v) => ({ ...prev, ...v }), {});
        }
        else if (typeof options.headers === 'object') {
            headers = options.headers;
        }
    }
    const fetchFn = typeof fetch === 'undefined' ? eval(`require('cross-fetch').fetch`) : fetch;
    let extraHeaders = {
        Accept: 'application/json',
        'Content-Type': 'application/json',
        ...headers,
    };
    const response = await fetchFn(url, {
        method: 'POST',
        body: JSON.stringify({
            query: introspectionQuery_1.introspectionQuery,
        }),
        headers: extraHeaders,
    });
    const body = await response.json();
    let errorMessage;
    if (body.errors && body.errors.length > 0) {
        errorMessage = body.errors.map((item) => item.message).join(', ');
    }
    else if (!body.data) {
        errorMessage = body;
    }
    if (errorMessage) {
        throw 'Unable to download schema from remote: ' + errorMessage;
    }
    if (!body.data.__schema) {
        throw new Error('Invalid schema provided!');
    }
    const asSchema = buildClientSchema_1.buildClientSchema(body.data);
    const printed = print_schema_with_directives_1.printSchemaWithDirectives(asSchema);
    return parser_1.parse(printed);
}
exports.loadFromUrl = loadFromUrl;
//# sourceMappingURL=load-from-url.js.map