"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const resolvers_composition_1 = require("./resolvers-composition");
const parser_1 = require("graphql/language/parser");
const buildASTSchema_1 = require("graphql/utilities/buildASTSchema");
const definition_1 = require("graphql/type/definition");
function buildSchemaWithResolvers({ typeDefs, resolvers, resolversComposition }) {
    if (typeof typeDefs === 'string') {
        typeDefs = parser_1.parse(typeDefs);
    }
    const schema = buildASTSchema_1.buildASTSchema(typeDefs);
    if (resolvers) {
        if (resolversComposition) {
            resolvers = resolvers_composition_1.composeResolvers(resolvers, resolversComposition);
        }
        const typeMap = schema.getTypeMap();
        for (const typeName in resolvers) {
            if (typeName in typeMap) {
                const typeResolvers = resolvers[typeName];
                const type = typeMap[typeName];
                if (type instanceof definition_1.GraphQLScalarType) {
                    Object.assign(typeMap[typeName], typeResolvers);
                }
                else if (type instanceof definition_1.GraphQLObjectType || type instanceof definition_1.GraphQLInterfaceType) {
                    const fields = type.getFields();
                    for (const fieldName in typeResolvers) {
                        if (type instanceof definition_1.GraphQLInterfaceType && fieldName === '__resolveType') {
                            type.resolveType = typeResolvers.__resolveType;
                        }
                        else if (type instanceof definition_1.GraphQLObjectType && fieldName === '__isTypeOf') {
                            type.isTypeOf = typeResolvers.__isTypeOf;
                        }
                        else if (fieldName in fields) {
                            const fieldResolver = typeResolvers[fieldName];
                            if ('subscribe' in fieldResolver) {
                                fields[fieldName].subscribe = fieldResolver.subscribe;
                            }
                            if ('resolve' in fieldResolver) {
                                fields[fieldName].resolve = fieldResolver.resolve;
                            }
                            if (fieldResolver instanceof Function) {
                                fields[fieldName].resolve = typeResolvers[fieldName].bind(typeResolvers);
                            }
                        }
                    }
                }
                else if (type instanceof definition_1.GraphQLEnumType) {
                    const enumValues = type.getValues();
                    for (const enumValue of enumValues) {
                        if (enumValue.name in typeResolvers) {
                            enumValue.value = typeResolvers[enumValue.name];
                        }
                    }
                }
                else if (type instanceof definition_1.GraphQLUnionType) {
                    if ('__resolveType' in typeResolvers) {
                        type.resolveType = typeResolvers.__resolveType;
                    }
                }
            }
        }
    }
    return schema;
}
exports.buildSchemaWithResolvers = buildSchemaWithResolvers;
//# sourceMappingURL=build-schema-with-resolvers.js.map