"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const extract_field_resolvers_from_object_type_1 = require("./extract-field-resolvers-from-object-type");
const buildASTSchema_1 = require("graphql/utilities/buildASTSchema");
const definition_1 = require("graphql/type/definition");
const parser_1 = require("graphql/language/parser");
function extractResolversFromSchema(schema, options) {
    const resolvers = {};
    const typeMap = schema.getTypeMap();
    let selectedTypeNames;
    const selectedTypeDefs = options && options.selectedTypeDefs && (typeof options.selectedTypeDefs === 'string' ? parser_1.parse(options.selectedTypeDefs) : options.selectedTypeDefs);
    if (selectedTypeDefs) {
        const invalidSchema = buildASTSchema_1.buildASTSchema(selectedTypeDefs);
        selectedTypeNames = Object.keys(invalidSchema.getTypeMap());
    }
    for (const typeName in typeMap) {
        if (!typeName.startsWith('__')) {
            const typeDef = typeMap[typeName];
            if (selectedTypeNames && !selectedTypeNames.includes(typeName)) {
                continue;
            }
            if (typeDef instanceof definition_1.GraphQLScalarType) {
                resolvers[typeName] = typeDef;
            }
            else if (typeDef instanceof definition_1.GraphQLObjectType || typeDef instanceof definition_1.GraphQLInterfaceType) {
                resolvers[typeName] = extract_field_resolvers_from_object_type_1.extractFieldResolversFromObjectType(typeDef, {
                    selectedTypeDefs,
                });
            }
            else if (typeDef instanceof definition_1.GraphQLEnumType) {
                const enumValues = typeDef.getValues();
                resolvers[typeName] = {};
                for (const { name, value } of enumValues) {
                    resolvers[typeName][name] = value;
                }
            }
            else if (typeDef instanceof definition_1.GraphQLUnionType) {
                resolvers[typeName] = {
                    __resolveType: typeDef.resolveType,
                };
            }
        }
    }
    return resolvers;
}
exports.extractResolversFromSchema = extractResolversFromSchema;
//# sourceMappingURL=extract-resolvers-from-schema.js.map