import { mergeTypeDefs } from "./typedefs-mergers/merge-typedefs";
import { mergeResolvers } from "./resolvers-mergers/merge-resolvers";
import { composeResolvers } from '../utils/resolvers-composition';
import { buildSchemaWithResolvers } from '../utils/build-schema-with-resolvers';
import { extractResolversFromSchema } from '../utils/extract-resolvers-from-schema';
export function mergeSchemas({ schemas, typeDefs, resolvers = {}, resolversComposition = {}, exclusions, }) {
    return buildSchemaWithResolvers({
        typeDefs: mergeTypeDefs(typeDefs ? [
            ...schemas,
            typeDefs,
        ] : schemas, { exclusions }),
        resolvers: composeResolvers(mergeResolvers([
            ...schemas.map(schema => extractResolversFromSchema(schema)),
            resolvers,
        ], { exclusions }), resolversComposition)
    });
}
export async function mergeSchemasAsync({ schemas, typeDefs, resolvers = {}, resolversComposition = {}, exclusions, }) {
    const [typeDefsOutput, resolversOutput,] = await Promise.all([
        mergeTypeDefs(typeDefs ? [
            ...schemas,
            typeDefs,
        ] : schemas, { exclusions }),
        Promise
            .all(schemas.map(async (schema) => extractResolversFromSchema(schema)))
            .then(extractedResolvers => composeResolvers(mergeResolvers([
            ...extractedResolvers,
            resolvers,
        ], { exclusions }), resolversComposition)),
    ]);
    return buildSchemaWithResolvers({
        typeDefs: typeDefsOutput,
        resolvers: resolversOutput
    });
}
//# sourceMappingURL=merge-schemas.js.map