import { extractFieldResolversFromObjectType } from "./extract-field-resolvers-from-object-type";
import { buildASTSchema } from 'graphql/utilities/buildASTSchema';
import { GraphQLScalarType, GraphQLObjectType, GraphQLInterfaceType, GraphQLEnumType, GraphQLUnionType } from 'graphql/type/definition';
import { parse } from 'graphql/language/parser';
export function extractResolversFromSchema(schema, options) {
    const resolvers = {};
    const typeMap = schema.getTypeMap();
    let selectedTypeNames;
    const selectedTypeDefs = options && options.selectedTypeDefs && (typeof options.selectedTypeDefs === 'string' ? parse(options.selectedTypeDefs) : options.selectedTypeDefs);
    if (selectedTypeDefs) {
        const invalidSchema = buildASTSchema(selectedTypeDefs);
        selectedTypeNames = Object.keys(invalidSchema.getTypeMap());
    }
    for (const typeName in typeMap) {
        if (!typeName.startsWith('__')) {
            const typeDef = typeMap[typeName];
            if (selectedTypeNames && !selectedTypeNames.includes(typeName)) {
                continue;
            }
            if (typeDef instanceof GraphQLScalarType) {
                resolvers[typeName] = typeDef;
            }
            else if (typeDef instanceof GraphQLObjectType || typeDef instanceof GraphQLInterfaceType) {
                resolvers[typeName] = extractFieldResolversFromObjectType(typeDef, {
                    selectedTypeDefs,
                });
            }
            else if (typeDef instanceof GraphQLEnumType) {
                const enumValues = typeDef.getValues();
                resolvers[typeName] = {};
                for (const { name, value } of enumValues) {
                    resolvers[typeName][name] = value;
                }
            }
            else if (typeDef instanceof GraphQLUnionType) {
                resolvers[typeName] = {
                    __resolveType: typeDef.resolveType,
                };
            }
        }
    }
    return resolvers;
}
//# sourceMappingURL=extract-resolvers-from-schema.js.map